@@ -630,8 +630,7 @@ short
 findAllele (data_fmt * data, char s[], long locus)
 {
     short found = 0;
-    while ((strcmp (s, data->allele[locus][found])
-            && data->allele[locus][found][0] != '\0'))
+    while (data->allele[locus][found]!=NULL && (data->allele[locus][found][0] != '\0') &&(strcmp (s, data->allele[locus][found])))
         found++;
     return found;
 }
@@ -2454,7 +2453,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
   fprintf(outfile,"%5.3f\n\n",avghet1/data->loci);
   // printd in PDF
 #ifdef PRETTY
-  pdf_print_spectra(data, options, freq, total, grandtotal, avghet, avghet1, maxalleles);
+  //pdf_print_spectra(data, options, freq, total, grandtotal, avghet, avghet1, maxalleles);
 #endif
   fflush(outfile);
   // cleanup
@@ -2731,9 +2730,13 @@ create_alleles (data_fmt * data, option_fmt *options)
   MYREAL  delta=0.;
   long locus, pop, ind;
   long z;
-  char a1[LINESIZE];//DEFAULT_ALLELENMLENGTH];
-  char a2[LINESIZE];//DEFAULT_ALLELENMLENGTH];
+  char *a1;//DEFAULT_ALLELENMLENGTH];
+  char *a2;//DEFAULT_ALLELENMLENGTH];
   boolean second = (strchr(ALLELETYPES,options->datatype)!=NULL);
+  a1 = (char *) malloc(sizeof(char)*LINESIZE);
+  a2 = (char *) malloc(sizeof(char)*LINESIZE);
+  long lena1 = LINESIZE;
+  long lena2 = LINESIZE;
   for (locus = 0; locus < data->loci; locus++)
     {
       if(data->repeatlength[locus]!=0)
@@ -2744,57 +2747,73 @@ create_alleles (data_fmt * data, option_fmt *options)
             for (ind = 0; ind < data->numind[pop][locus]; ind++)
             {
 
-                strcpy (a1, data->yy[pop][ind][locus][0]);
-		if(second)
-		  {
-		    strcpy (a2, data->yy[pop][ind][locus][1]);
-		    if (!strcmp (a1, a2))
-		      {
-			addAllele (data, a1, locus, &z);
-		      }
-		    else
-		      {
-			addAllele (data, a1, locus, &z);
-			addAllele (data, a2, locus, &z);
-		      }
-		  }
-		else
-		  {
-		    addAllele (data, a1, locus, &z);
-		  }
+	      char *data1 = data->yy[pop][ind][locus][0];
+	      long lendata1 = strlen(data1);
+	      if (lena1 < lendata1)
+		{
+		  a1 = (char *) realloc(a1,sizeof(char)*(lendata1+1));
+		  lena1 = lendata1 + 1;
+		}
+	      strcpy (a1, data1);
+	      if(second)
+		{
+		  char *data2 = data->yy[pop][ind][locus][1];
+		  long lendata2 = strlen(data2);
+		  if (lena2 < lendata2)
+		    {
+		      a2 = (char *) realloc(a2,sizeof(char)*(lendata2+1));
+		      lena2 = lendata2 + 1;
+		    }
+		  strcpy (a2, data2);
+		  if (!strcmp (a1, a2))
+		    {
+		      addAllele (data, a1, locus, &z);
+		    }
+		  else
+		    {
+		      addAllele (data, a1, locus, &z);
+		      addAllele (data, a2, locus, &z);
+		    }
+		}
+	      else
+		{
+		  addAllele (data, a1, locus, &z);
+		}
 	    }
-        }
-	if(z<=1)
-	  {
-	    data->skiploci[locus] = TRUE;// this skips loci with _no_ data
-	    continue;
-	  }
-
-        data->maxalleles[locus] = z + 1;
-        /* + 1: for all the unencountered alleles */
-	if(options->murates_fromdata)
-	  {
-	    if(options->mu_rates==NULL)
-	      {
-		options->mu_rates = (MYREAL * ) mycalloc(data->loci,sizeof(MYREAL));
-		//		printf("%i> data.c: 1557 murate size %li\n",myID,data->loci * sizeof (MYREAL));
-	      }
-	    options->mu_rates[locus] = z+1;
-	    n = n + 1;
-	    delta = options->mu_rates[locus] - mean;
-	    mean += delta/n;
-	  }
+	}
+      if(z<=1)
+	{
+	  data->skiploci[locus] = TRUE;// this skips loci with _no_ data
+	  continue;
+	}
+      
+      data->maxalleles[locus] = z + 1;
+      /* + 1: for all the unencountered alleles */
+      if(options->murates_fromdata)
+	{
+	  if(options->mu_rates==NULL)
+	    {
+	      options->mu_rates = (MYREAL * ) mycalloc(data->loci,sizeof(MYREAL));
+	      //		printf("%i> data.c: 1557 murate size %li\n",myID,data->loci * sizeof (MYREAL));
+	    }
+	  options->mu_rates[locus] = z+1;
+	  n = n + 1;
+	  delta = options->mu_rates[locus] - mean;
+	  mean += delta/n;
+	}
     }
-    if(options->murates_fromdata)
-      {
-	options->muloci = data->loci;
-	for (locus=0; locus < data->loci; locus++)
-	  {
-	    if(!data->skiploci[locus])
-	      options->mu_rates[locus] /= mean;
-	  }
-      }
-    return mean;
+  if(options->murates_fromdata)
+    {
+      options->muloci = data->loci;
+      for (locus=0; locus < data->loci; locus++)
+	{
+	  if(!data->skiploci[locus])
+	    options->mu_rates[locus] /= mean;
+	}
+    }
+  myfree(a1);
+  myfree(a2);
+  return mean;
 }
 
 void
