@@ -14,11 +14,26 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
- This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
+ Permission is hereby granted, free of charge, to any person obtaining
+ a copy of this software and associated documentation files (the
+ "Software"), to deal in the Software without restriction, including
+ without limitation the rights to use, copy, modify, merge, publish,
+ distribute, sublicense, and/or sell copies of the Software, and to
+ permit persons to whom the Software is furnished to do so, subject
+ to the following conditions:
  
-$Id: mcmc2.c 1573 2009-08-29 14:01:49Z beerli $
+ The above copyright notice and this permission notice shall be
+ included in all copies or substantial portions of the Software.
+ 
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
+ ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
+ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ 
+$Id: mcmc2.c 2158 2013-04-29 01:56:20Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc2.c
 Contains low-level routines to manipulate the treechanger
@@ -112,13 +127,13 @@ coalesce1p (proposal_fmt * proposal)
                 || (proposal->target == proposal->osister)
                 || (proposal->target == proposal->origin)))
         {
-            obb = proposal->oback->back;
+            //xcode obb = proposal->oback->back;
             coat_oback (proposal);
             if (proposal->oback->tyme > showtop (proposal->oback->back)->tyme)
             {   /* was >= ** */
                 if (proposal->oback->back->type == 'r')
                 {
-                    adjust (proposal->root, proposal->oback->tyme + 10000, 0);
+                    adjust (proposal->root, proposal->oback->tyme + 10000, 0L);
                     comment ("Root time adjusted: was to small");
                 }
                 else
@@ -136,7 +151,7 @@ coalesce1p (proposal_fmt * proposal)
                     if (proposal->oback->back->type == 'r')
                     {
                         adjust (proposal->root, proposal->oback->tyme + 10000,
-                                0);
+                                0L);
                         comment ("Root time adjusted: was to small");
                     }
                     else
@@ -274,7 +289,7 @@ coat_oback (proposal_fmt * proposal)
     {
       connectnodes (proposal->world,obb, proposal->oback, proposal->ocousin);
     }
-    adjust (obb, obb->tyme, 2);
+    adjust (obb, obb->tyme, 2L);
     set_dirty (proposal->oback);
     localevaluate (proposal->oback);
 }
@@ -295,7 +310,7 @@ coat_ocousin (proposal_fmt * proposal)
     connectnodes (proposal->world,rcback, proposal->oback, NULL);
     connectnodes (proposal->world,proposal->oback, proposal->ocousin, proposal->origin);
     connectnodes (proposal->world,obb, proposal->oback, proposal->osister);
-    adjust (obb, obb->tyme, 2);
+    adjust (obb, obb->tyme, 2L);
     set_dirty (proposal->oback);
     set_dirty (obb);
     if (crawlback (obb)->type != 'r')
@@ -316,12 +331,12 @@ coat_rbcoa (proposal_fmt * proposal)
         root = proposal->root;
         connectnodes (proposal->world,showtop (proposal->oback->back), proposal->osister, NULL);
         connectnodes (proposal->world,obb, proposal->ocousin, proposal->osister);
-        adjust (obb, obb->tyme, 2);
+        adjust (obb, obb->tyme, 2L);
         adjust_time (proposal->oback, proposal->time);
         proposal->oback->back = NULL;
         connectnodes (proposal->world,proposal->oback, proposal->origin, proposal->target);
         connectnodes (proposal->world,root, proposal->oback, NULL);
-        adjust (proposal->oback, proposal->time, 2);
+        adjust (proposal->oback, proposal->time, 2L);
         set_dirty (obb);
         set_dirty (proposal->oback);
         localevaluate (showtop (crawlback (obb)));
@@ -348,7 +363,7 @@ coat_obbcoa (proposal_fmt * proposal)
 	       proposalack = showtop (crawlback (proposal->target));
         adjust_time (proposal->oback, proposal->time);
         connectnodes (proposal->world,proposal->target, proposal->ocousin, proposal->osister);
-        adjust (proposal->target, proposal->target->tyme, 1);
+        adjust (proposal->target, proposal->target->tyme, 1L);
         proposal->oback->back = NULL;
         adjust_time (proposal->oback, proposal->time);
         if (showtop (proposal->realtarget->back)->type == 'm')
@@ -358,7 +373,7 @@ coat_obbcoa (proposal_fmt * proposal)
         }
         connectnodes (proposal->world,proposal->oback, proposal->origin, proposal->target);
         connectnodes (proposal->world,proposalack, proposal->tsister, proposal->oback);
-        adjust (proposalack, proposalack->tyme, 2);
+        adjust (proposalack, proposalack->tyme, 2L);
         set_dirty (proposal->target);
         set_dirty (proposal->oback);
         localevaluate (proposalack);
@@ -393,8 +408,8 @@ coat_stancoa (proposal_fmt * proposal)
 	  }
         connectnodes (proposal->world,proposal->oback, proposal->origin, proposal->target);
         connectnodes (proposal->world,proposalack, proposal->oback, proposal->tsister);
-        adjust (proposalack, proposalack->tyme, 3);
-        adjust (obb, obb->tyme, 3);
+        adjust (proposalack, proposalack->tyme, 3L);
+        adjust (obb, obb->tyme, 3L);
         set_dirty (obb);
         set_dirty (proposal->oback);
         localevaluate (proposalack);
@@ -417,8 +432,8 @@ coat_stancoa (proposal_fmt * proposal)
         /* either proposalack is osister or a descendent of her
            other case are disallowed by time constraints */
         connectnodes (proposal->world,obb, proposal->osister, NULL);
-        adjust (proposalack, proposalack->tyme, 3);
-        adjust (obb, obb->tyme, 3);
+        adjust (proposalack, proposalack->tyme, 3L);
+        adjust (obb, obb->tyme, 3L);
         set_dirty (proposal->oback);
         localevaluate (proposalack);
 
@@ -1264,10 +1279,11 @@ erase_migr_nodes2 (world_fmt *world, node * up)
 {
   int skip=0;
     long deleted = 0;
-    node *theNode, *down, *oldNode;
+    node *theNode, *oldNode;
+    //node *down
     if(skip!=0)
       return;
-    down = crawlback (up);
+    //xcode down = crawlback (up);
     theNode = showtop(up->back);
     //    printf("-------------\nup=%li\n",up->id);
     while (theNode->type == 'm')
