@@ -734,7 +734,7 @@ randum_thread (void)
 /* thread save random number generator */
 {
     MYREAL value;
-    if ((pthread_mutex_lock (&(heating_pool->random_lock))) != 0)
+    if (heating_pool != NULL && (pthread_mutex_lock (&(heating_pool->random_lock))) != 0)
         error ("pthread_mutex_lock failed in random_thread()");
 #ifdef MERSENNE_TWISTER
     value = genrand_res53();
@@ -752,7 +752,7 @@ randum_thread (void)
     seed[2] &= 1023;
     value = (((seed[0] / 2048.0 + seed[1]) / 2048.0 + seed[2]) / 1024.0);
 #endif
-    if ((pthread_mutex_unlock (&(heating_pool->random_lock))) != 0)
+    if (heating_pool != NULL && (pthread_mutex_unlock (&(heating_pool->random_lock))) != 0)
         error ("pthread_mutex_unlock failed in randum_thread()");
     return value;
 }    /* threaded randum */
